==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/CognitoIdp/DeleteUserAttributes.pm <==

package Paws::CognitoIdp::DeleteUserAttributes;
  use Moose;
  has AccessToken => (is => 'ro', isa => 'Str', required => 1);
  has UserAttributeNames => (is => 'ro', isa => 'ArrayRef[Str|Undef]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteUserAttributes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CognitoIdp::DeleteUserAttributesResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::DeleteUserAttributes - Arguments for method DeleteUserAttributes on Paws::CognitoIdp

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteUserAttributes on the 
Amazon Cognito Identity Provider service. Use the attributes of this class
as arguments to method DeleteUserAttributes.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteUserAttributes.

As an example:

  $service_obj->DeleteUserAttributes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccessToken => Str

The access token used in the request to delete user attributes.



=head2 B<REQUIRED> UserAttributeNames => ArrayRef[Str|Undef]

An array of strings representing the user attribute names you wish to
delete.

For custom attributes, you must prepend the C<custom:> prefix to the
attribute name.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteUserAttributes in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/CognitoIdp/DeleteUserAttributes.pm <==

package Paws::CognitoIdp::DeleteUserAttributes;
  use Moose;
  has AccessToken => (is => 'ro', isa => 'Str', required => 1);
  has UserAttributeNames => (is => 'ro', isa => 'ArrayRef[Str|Undef]', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteUserAttributes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CognitoIdp::DeleteUserAttributesResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::DeleteUserAttributes - Arguments for method DeleteUserAttributes on L<Paws::CognitoIdp>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteUserAttributes on the
L<Amazon Cognito Identity Provider|Paws::CognitoIdp> service. Use the attributes of this class
as arguments to method DeleteUserAttributes.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteUserAttributes.

=head1 SYNOPSIS

    my $cognito-idp = Paws->service('CognitoIdp');
    my $DeleteUserAttributesResponse = $cognito -idp->DeleteUserAttributes(
      AccessToken        => 'MyTokenModelType',
      UserAttributeNames => [
        'MyAttributeNameType', ...    # min: 1, max: 32
      ],

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/cognito-idp/DeleteUserAttributes>

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccessToken => Str

The access token used in the request to delete user attributes.



=head2 B<REQUIRED> UserAttributeNames => ArrayRef[Str|Undef]

An array of strings representing the user attribute names you wish to
delete.

For custom attributes, you must prepend the C<custom:> prefix to the
attribute name.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteUserAttributes in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
